agent_step

Function agent_step 

pub fn agent_step(snapshot: &Value, goal: &str, history: &[Value]) -> AgentStep
Builds the questions for one step from a snapshot, the goal and the actions taken so far.