pub fn laya_answer(
q: &Question,
logits: &[f32],
act: [f32; 2],
temps: &Temperatures,
) -> AnswerExpand description
The answer to q from its option logits, in option order, and its two act logits.
Panics
If logits does not have one value per option.